/*
 *
 * (C) 2019-25 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef _ALERT_H_
#define _ALERT_H_

class Alert {
 public:
  time_t tstamp;
  time_t last_update;
  AlertType alert_id;
  u_int64_t rowid; /* used by engaged alert in the in-memory table */
  u_int16_t port;
  u_int8_t score;
  bool require_attention;
  std::string subtype;
  std::string json;
  std::string ip;
  std::string name;
};

#endif
